==> lambda-event-sources-1.131.0-sources.jar: software/amazon/awscdk/services/lambda/eventsources/S3EventSource.java <==
package software.amazon.awscdk.services.lambda.eventsources;

/**
 * Use S3 bucket notifications as an event source for AWS Lambda.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.42.0 (build 5f6b62c)", date = "2021-11-07T11:30:02.910Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.lambda.eventsources.$Module.class, fqn = "@aws-cdk/aws-lambda-event-sources.S3EventSource")
public class S3EventSource extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.lambda.IEventSource {

    protected S3EventSource(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected S3EventSource(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param bucket This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public S3EventSource(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.s3.Bucket bucket, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.eventsources.S3EventSourceProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(bucket, "bucket is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * Called by `lambda.addEventSource` to allow the event source to bind to this function.
     * <p>
     * @param target This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    public void bind(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.IFunction target) {
        software.amazon.jsii.Kernel.call(this, "bind", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(target, "target is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.s3.Bucket getBucket() {
        return software.amazon.jsii.Kernel.get(this, "bucket", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.s3.Bucket.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awscdk.services.lambda.eventsources.S3EventSource}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.lambda.eventsources.S3EventSource> {
        /**
         * @return a new instance of {@link Builder}.
         * @param bucket This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create(final software.amazon.awscdk.services.s3.Bucket bucket) {
            return new Builder(bucket);
        }

        private final software.amazon.awscdk.services.s3.Bucket bucket;
        private final software.amazon.awscdk.services.lambda.eventsources.S3EventSourceProps.Builder props;

        private Builder(final software.amazon.awscdk.services.s3.Bucket bucket) {
            this.bucket = bucket;
            this.props = new software.amazon.awscdk.services.lambda.eventsources.S3EventSourceProps.Builder();
        }

        /**
         * The s3 event types that will trigger the notification.
         * <p>
         * @return {@code this}
         * @param events The s3 event types that will trigger the notification. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder events(final java.util.List<? extends software.amazon.awscdk.services.s3.EventType> events) {
            this.props.events(events);
            return this;
        }

        /**
         * S3 object key filter rules to determine which objects trigger this event.
         * <p>
         * Each filter must include a <code>prefix</code> and/or <code>suffix</code> that will be matched
         * against the s3 object key. Refer to the S3 Developer Guide for details
         * about allowed filter rules.
         * <p>
         * @return {@code this}
         * @param filters S3 object key filter rules to determine which objects trigger this event. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder filters(final java.util.List<? extends software.amazon.awscdk.services.s3.NotificationKeyFilter> filters) {
            this.props.filters(filters);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.services.lambda.eventsources.S3EventSource}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public software.amazon.awscdk.services.lambda.eventsources.S3EventSource build() {
            return new software.amazon.awscdk.services.lambda.eventsources.S3EventSource(
                this.bucket,
                this.props.build()
            );
        }
    }
}

==> lambda-event-sources-1.147.0-sources.jar: software/amazon/awscdk/services/lambda/eventsources/S3EventSource.java <==
package software.amazon.awscdk.services.lambda.eventsources;

/**
 * Use S3 bucket notifications as an event source for AWS Lambda.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * import software.amazon.awscdk.services.lambda.eventsources.*;
 * import software.amazon.awscdk.services.s3.*;
 * Function fn;
 * Bucket bucket = new Bucket(this, "Bucket");
 * fn.addEventSource(S3EventSource.Builder.create(bucket)
 *         .events(List.of(EventType.OBJECT_CREATED, EventType.OBJECT_REMOVED))
 *         .filters(List.of(NotificationKeyFilter.builder().prefix("subdir/").build()))
 *         .build());
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.54.0 (build b1b977a)", date = "2022-03-01T02:29:06.765Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.lambda.eventsources.$Module.class, fqn = "@aws-cdk/aws-lambda-event-sources.S3EventSource")
public class S3EventSource extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.lambda.IEventSource {

    protected S3EventSource(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected S3EventSource(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param bucket This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public S3EventSource(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.s3.Bucket bucket, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.eventsources.S3EventSourceProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(bucket, "bucket is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * Called by `lambda.addEventSource` to allow the event source to bind to this function.
     * <p>
     * @param target This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    public void bind(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.IFunction target) {
        software.amazon.jsii.Kernel.call(this, "bind", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(target, "target is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.s3.Bucket getBucket() {
        return software.amazon.jsii.Kernel.get(this, "bucket", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.s3.Bucket.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awscdk.services.lambda.eventsources.S3EventSource}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.lambda.eventsources.S3EventSource> {
        /**
         * @return a new instance of {@link Builder}.
         * @param bucket This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create(final software.amazon.awscdk.services.s3.Bucket bucket) {
            return new Builder(bucket);
        }

        private final software.amazon.awscdk.services.s3.Bucket bucket;
        private final software.amazon.awscdk.services.lambda.eventsources.S3EventSourceProps.Builder props;

        private Builder(final software.amazon.awscdk.services.s3.Bucket bucket) {
            this.bucket = bucket;
            this.props = new software.amazon.awscdk.services.lambda.eventsources.S3EventSourceProps.Builder();
        }

        /**
         * The s3 event types that will trigger the notification.
         * <p>
         * @return {@code this}
         * @param events The s3 event types that will trigger the notification. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder events(final java.util.List<? extends software.amazon.awscdk.services.s3.EventType> events) {
            this.props.events(events);
            return this;
        }

        /**
         * S3 object key filter rules to determine which objects trigger this event.
         * <p>
         * Each filter must include a <code>prefix</code> and/or <code>suffix</code> that will be matched
         * against the s3 object key. Refer to the S3 Developer Guide for details
         * about allowed filter rules.
         * <p>
         * @return {@code this}
         * @param filters S3 object key filter rules to determine which objects trigger this event. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder filters(final java.util.List<? extends software.amazon.awscdk.services.s3.NotificationKeyFilter> filters) {
            this.props.filters(filters);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.services.lambda.eventsources.S3EventSource}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public software.amazon.awscdk.services.lambda.eventsources.S3EventSource build() {
            return new software.amazon.awscdk.services.lambda.eventsources.S3EventSource(
                this.bucket,
                this.props.build()
            );
        }
    }
}
